@@ -15,7 +15,11 @@ import socket
 from copy import copy
 from itertools import count
 from Queue import Empty
-from urlparse import urlparse, parse_qsl
+from urlparse import urlparse
+try:
+    from urlparse import parse_qsl
+except ImportError:
+    from cgi import parse_qsl
 
 from kombu import exceptions
 from kombu.transport import get_transport_cls
@@ -456,18 +460,6 @@ class BrokerConnection(object):
         """
         return ChannelPool(self, limit, preload)
 
-    def Producer(self, channel=None, *args, **kwargs):
-        from kombu.messaging import Producer
-        if channel is None:
-            channel = self   # use default channel support.
-        return Producer(channel, *args, **kwargs)
-
-    def Consumer(self, channel=None, *args, **kwargs):
-        from kombu.messaging import Consumer
-        if channel is None:
-            channel = self  # use default channel support.
-        return Consumer(channel, *args, **kwargs)
-
     def SimpleQueue(self, name, no_ack=None, queue_opts=None,
             exchange_opts=None, channel=None, **kwargs):
         """Create new :class:`~kombu.simple.SimpleQueue`, using a channel
