@@ -5,12 +5,6 @@ from itertools import chain
 
 __all__ = ["ProducerPool", "connections", "producers", "set_limit", "reset"]
 _limit = [200]
-_groups = []
-
-
-def register_group(group):
-    _groups.append(group)
-    return group
 
 
 class ProducerPool(Resource):
@@ -22,8 +16,10 @@ class ProducerPool(Resource):
 
     def create_producer(self):
         conn = self.connections.acquire(block=True)
-        producer = self.Producer(conn)
+        channel = conn.channel()
+        producer = self.Producer(channel)
         producer.connection = conn
+        conn._producer_chan = channel
         return producer
 
     def new(self):
@@ -39,7 +35,9 @@ class ProducerPool(Resource):
             p = p()
         if not p.connection:
             p.connection = self.connections.acquire(block=True)
-            p.revive(p.connection.default_channel)
+            if not getattr(p.connection, "_producer_chan", None):
+                p.connection._producer_chan = p.connection.channel()
+            p.revive(p.connection._producer_chan)
         return p
 
     def release(self, resource):
@@ -63,50 +61,44 @@ class HashingDict(dict):
         return dict.__delitem__(self, hash(key))
 
 
-class PoolGroup(HashingDict):
+class _Connections(HashingDict):
 
-    def create(self, resource, limit):
-        raise NotImplementedError("PoolGroups must define ``create``")
-
-    def __missing__(self, resource):
-        k = self[resource] = self.create(resource, _limit[0])
+    def __missing__(self, connection):
+        k = self[connection] = connection.Pool(limit=_limit[0])
         return k
-
-
-class _Connections(PoolGroup):
-
-    def create(self, connection, limit):
-        return connection.Pool(limit=limit)
-connections = register_group(_Connections())
+connections = _Connections()
 
 
 class _Producers(HashingDict):
 
-    def create(self, connection, limit):
-        return ProducerPool(connections[connection], limit=limit)
-producers = register_group(_Producers())
+    def __missing__(self, conn):
+        k = self[conn] = ProducerPool(connections[conn], limit=_limit[0])
+        return k
+producers = _Producers()
 
 
 def _all_pools():
-    return chain(*[(g.itervalues() if g else iter([])) for g in _groups])
+    return chain(connections.itervalues() if connections else iter([]),
+                 producers.itervalues() if producers else iter([]))
 
 
 def set_limit(limit):
     _limit[0] = limit
     for pool in _all_pools():
         pool.limit = limit
-    reset()
     return limit
 
 
-def reset(*args, **kwargs):
+def reset():
+    global connections
+    global producers
     for pool in _all_pools():
         try:
             pool.force_close_all()
         except Exception:
             pass
-    for group in _groups:
-        group.clear()
+    connections = _Connections()
+    producers._Producers()
 
 
 try:
